==> yy-formulas-1.0.20.tgz: package/es/components/DocumentComponents.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (typeof call === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import { polyfill } from 'react-lifecycles-compat';
import Tree, { TreeNode } from 'rc-tree'; // import jQuery from 'jquery'

var DocumentComponents =
/*#__PURE__*/
function (_React$Component) {
  _inherits(DocumentComponents, _React$Component);

  function DocumentComponents(props) {
    var _this;

    _classCallCheck(this, DocumentComponents);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(DocumentComponents).call(this, props));
    _this.onSelect = _this.onSelect.bind(_assertThisInitialized(_this));
    _this.onDoubleClick = _this.onDoubleClick.bind(_assertThisInitialized(_this));
    _this.onChange = _this.onChange.bind(_assertThisInitialized(_this));
    _this.onButClick = _this.onButClick.bind(_assertThisInitialized(_this));
    _this.loop = _this.loop.bind(_assertThisInitialized(_this));
    _this.setFname = _this.setFname.bind(_assertThisInitialized(_this));
    var DocumentTreeData = _this.props.DocumentTreeData;
    _this.state = {
      selectedKeys: [],
      value: '',
      expandedKeys: DocumentTreeData.length > 0 && DocumentTreeData[0].key ? [DocumentTreeData[0].key] : [],
      selectedKeysList: []
    };
    return _this;
  }

  _createClass(DocumentComponents, [{
    key: "onDoubleClick",
    value: function onDoubleClick(item) {
      var code = item.code;
      var key = code.substr(code.indexOf('.') + 1);
      this.props.onInsertValue(' ' + key + ' ');
    }
  }, {
    key: "onSelect",
    value: function onSelect(selectkey) {
      // console.log(selectkey,...arr);
      // console.log([selectkey,...arr])
      // let selectedKeys = []
      // if(selectkey.length > 0){
      //   selectedKeys = selectkey
      //   let code = selectkey[0]
      //   let key = code.substr(code.indexOf('.') + 1)
      //   this.props.onInsertValue(' '+key+ ' ')
      // }else if(this.state.selectedKeys.length > 0){
      //   let code = this.state.selectedKeys[0]
      //   let key = code.substr(code.indexOf('.') + 1)
      //   this.props.onInsertValue(' '+key+ ' ')
      // }
      // this.setState({selectedKeys})
      var selectedKeys = [];

      if (selectkey.length > 0) {
        selectedKeys = selectkey;
      }

      this.setState({
        selectedKeys: selectedKeys
      });
    }
  }, {
    key: "onChange",
    value: function onChange(event) {
      var value = event.target.value;
      this.setState({
        value: value,
        selectedKeysList: []
      });
    }
  }, {
    key: "onButClick",
    value: function onButClick() {
      var selectedKeysList = [];
      var value = this.state.value;
      var DocumentTreeData = this.props.DocumentTreeData;

      var loop = function loop(data) {
        data.map(function (item) {
          var reg = new RegExp(value, 'igm');

          if (reg.test(item.title)) {
            selectedKeysList.push(item);
          }

          if (item.children && item.children.length > 0) {
            loop(item.children);
          }
        });
      };

      if (value) {
        loop(DocumentTreeData);
      }

      this.setState({
        selectedKeysList: selectedKeysList
      });
      /*
      let selectedKeys = this.state.selectedKeys
      if(value){
        loop(DocumentTreeData)
        if(selectedKeysList.length > 0){
          if(selectedKeys.length === 0) {
            selectedKeys.push(selectedKeysList[0])
          }else{
            if(selectedKeysList.includes(selectedKeys[0])){
              let index = selectedKeysList.indexOf(selectedKeys[0])
              if(selectedKeysList.length>index){
                selectedKeys = [selectedKeysList[index+1]]
              }else{
                selectedKeys = [selectedKeysList[0]]
              }
            }else{
              selectedKeys=[selectedKeysList[0]]
            }
          }
        }
        this.setState({selectedKeys},()=>{
          let expandedKeys = []
          if(selectedKeys && selectedKeys.length>0 && selectedKeys[0]){
            let selectedKeysArr = selectedKeys[0].split('.')
            selectedKeysArr.pop()
            selectedKeysArr.forEach((k)=>{
              if(expandedKeys.length>0){
                expandedKeys.push(expandedKeys[expandedKeys.length-1]+'.'+k)
              }else{
                expandedKeys.push(k)
              }
            })
          }
          if(expandedKeys.length===0){
            expandedKeys = DocumentTreeData.length > 0 && DocumentTreeData[0].key ? [DocumentTreeData[0].key] : []
          }
          this.setState({expandedKeys},()=>{
            // console.log(this.heightcount,jQuery('.rc-tree.myCls.rc-tree-show-line'),jQuery('.rc-tree-treenode-selected'))
            // jQuery('.rc-tree-treenode-selected').focus()
            // $(selectedKeys[0]).focus()
            // if(jQuery('.rc-tree-treenode-selected') && jQuery('.rc-tree-treenode-selected').length>0){
            //   jQuery('.rc-tree-treenode-selected').focus()
            // }
            // document.getElementById(selectedKeys[0]).focus()
            // console.log(document.getElementById('mygundongtiao'))
            // if(jQuery('.rc-tree.myCls.rc-tree-show-line') && jQuery('.rc-tree.myCls.rc-tree-show-line').length>0 && jQuery('.rc-tree-treenode-selected') && jQuery('.rc-tree-treenode-selected').length){
            //   jQuery('.rc-tree.myCls.rc-tree-show-line').scrollTop = jQuery('.rc-tree-treenode-selected').offsetTop-100
            // }
            // console.log(document.getElementByclassName('yy-tab-content'), document.getElementByclassName('rc-tree-node-selected')) // $('. .rc-tree-node-selected')
            // setTimeout(()=>{
            //   console.log(document.getElementByclassName('yy-tab-content'), document.getElementByclassName('rc-tree-node-selected'))
            // },0)
          })
          // console.log(selectedKeys)
        })
      }
      // console.log([selectedKeysList,value,selectedKeys])
      */
    }
  }, {
    key: "loop",
    value: function loop(data) {
      var _this2 = this;

      var selectedKeysList = this.state.selectedKeysList;
      var value = this.state.value;

      if (value && selectedKeysList.length > 0) {
        // console.log(selectedKeysList)
        return selectedKeysList.map(function (item) {
          return React.createElement(TreeNode, {
            title: item.fname,
            isLeaf: true,
            key: item.key,
            code: item.code,
            disabled: item.disabled //className={isflag ? 'yy-search-selected' : ''}

          });
        });
      }

      return data.map(function (item) {
        // let isflag = false
        // if(value && value.length > 0){
        //   let reg = new RegExp(value,'igm')
        //   if(reg.test(item.title)){
        //     selectedKeys.push(item.key)
        //   }
        //   // console.log(isflag)
        // }else{
        //   // console.log(isflag)
        // }
        if (item.children && item.children.length > 0) {
          return React.createElement(TreeNode //title={item.title}
          , {
            title: React.createElement("span", {
              onDoubleClick: _this2.onDoubleClick.bind(_this2, item)
            }, item.title),
            isLeaf: false,
            key: item.key,
            code: item.code,
            disabled: item.disabled //className={isflag ? 'yy-search-selected' : ''}

          }, _this2.loop(item.children));
        } else {
          return React.createElement(TreeNode, {
            title: React.createElement("span", {
              onDoubleClick: _this2.onDoubleClick.bind(_this2, item)
            }, item.title),
            isLeaf: true,
            key: item.key,
            code: item.code,
            disabled: item.disabled //className={isflag ? 'yy-search-selected' : ''}

          });
        }
      });
    }
  }, {
    key: "setFname",
    value: function setFname(data, name) {
      var _this3 = this;

      return data.map(function (item) {
        var title = item.title,
            children = item.children;
        var fname = name ? name.trim() + '/' + title : title;
        item.fname = fname; // console.log(JSON.stringify(children));

        if (children && children.length > 0) {
          item.children = _this3.setFname(children, fname);
        }

        return item; // console.log()
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this4 = this;

      var DocumentTreeData = this.props.DocumentTreeData;
      DocumentTreeData = this.setFname(DocumentTreeData); // console.log(DocumentTreeData)
      // let defaultExpandedKeys = DocumentTreeData.length > 0 && DocumentTreeData[0].key ? [DocumentTreeData[0].key] : []
      // let value = this.state.value
      // let selectedKeys = []
      // const loop = (data)=>{
      //   // console.log(data)
      // }

      return React.createElement("div", {
        className: "yy-tab-content"
      }, React.createElement("form", {
        className: "form-inline"
      }, React.createElement("span", null, this.props.item.positionName), React.createElement("div", {
        className: "form-group"
      }, React.createElement("input", {
        className: "form-control",
        onChange: this.onChange,
        value: this.state.value,
        onKeyPress: function onKeyPress(event) {
          if (event.key === 'Enter') {
            event.preventDefault();
            event.stopPropagation();
            return false;
          }
        }
      })), React.createElement("button", {
        style: {
          marginLeft: '10px'
        },
        className: "btn btn-default",
        onClick: this.onButClick,
        type: "button"
      }, this.props.item.okName)), React.createElement(Tree, {
        id: "mygundongtiao",
        prefixCls: "rc-tree",
        showLine: true,
        showIcon: false,
        checkable: false // defaultExpandAll
        // defaultExpandedKeys={defaultExpandedKeys}
        ,
        expandedKeys: this.state.expandedKeys,
        onExpand: function onExpand(expandedKeys) {
          // console.log(expandedKeys)
          _this4.setState({
            expandedKeys: expandedKeys
          });
        },
        className: "myCls" // autoExpandParent
        // checkStrictly
        ,
        selectedKeys: this.state.selectedKeys,
        onSelect: this.onSelect //expandAction='doubleClick'

      }, this.loop(DocumentTreeData)));
    }
  }]);

  return DocumentComponents;
}(React.Component);

DocumentComponents.propTypes = {
  item: PropTypes.object,
  DocumentTreeData: PropTypes.array
};
DocumentComponents.defaultProps = {
  item: {},
  DocumentTreeData: []
};
polyfill(DocumentComponents);
export default DocumentComponents;

==> yy-formulas-1.0.21.tgz: package/es/components/DocumentComponents.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (typeof call === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import { polyfill } from 'react-lifecycles-compat';
import Tree, { TreeNode } from 'rc-tree'; // import jQuery from 'jquery'

var DocumentComponents =
/*#__PURE__*/
function (_React$Component) {
  _inherits(DocumentComponents, _React$Component);

  function DocumentComponents(props) {
    var _this;

    _classCallCheck(this, DocumentComponents);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(DocumentComponents).call(this, props));
    _this.onSelect = _this.onSelect.bind(_assertThisInitialized(_this));
    _this.onDoubleClick = _this.onDoubleClick.bind(_assertThisInitialized(_this));
    _this.onChange = _this.onChange.bind(_assertThisInitialized(_this));
    _this.onButClick = _this.onButClick.bind(_assertThisInitialized(_this));
    _this.loop = _this.loop.bind(_assertThisInitialized(_this));
    _this.setFname = _this.setFname.bind(_assertThisInitialized(_this));
    var DocumentTreeData = _this.props.DocumentTreeData;
    _this.state = {
      selectedKeys: [],
      value: '',
      expandedKeys: DocumentTreeData.length > 0 && DocumentTreeData[0].key ? [DocumentTreeData[0].key] : [],
      selectedKeysList: []
    };
    return _this;
  }

  _createClass(DocumentComponents, [{
    key: "onDoubleClick",
    value: function onDoubleClick(item) {
      var key = item.key;
      var code = key.substr(key.indexOf('.') + 1);
      this.props.onInsertValue(' ' + code + ' ');
    }
  }, {
    key: "onSelect",
    value: function onSelect(selectkey) {
      // console.log(selectkey,...arr);
      // console.log([selectkey,...arr])
      // let selectedKeys = []
      // if(selectkey.length > 0){
      //   selectedKeys = selectkey
      //   let code = selectkey[0]
      //   let key = code.substr(code.indexOf('.') + 1)
      //   this.props.onInsertValue(' '+key+ ' ')
      // }else if(this.state.selectedKeys.length > 0){
      //   let code = this.state.selectedKeys[0]
      //   let key = code.substr(code.indexOf('.') + 1)
      //   this.props.onInsertValue(' '+key+ ' ')
      // }
      // this.setState({selectedKeys})
      var selectedKeys = [];

      if (selectkey.length > 0) {
        selectedKeys = selectkey;
      }

      this.setState({
        selectedKeys: selectedKeys
      });
    }
  }, {
    key: "onChange",
    value: function onChange(event) {
      var value = event.target.value;
      this.setState({
        value: value,
        selectedKeysList: []
      });
    }
  }, {
    key: "onButClick",
    value: function onButClick() {
      var selectedKeysList = [];
      var value = this.state.value;
      var DocumentTreeData = this.props.DocumentTreeData;

      var loop = function loop(data) {
        data.map(function (item) {
          var reg = new RegExp(value, 'igm');

          if (reg.test(item.title)) {
            selectedKeysList.push(item);
          }

          if (item.children && item.children.length > 0) {
            loop(item.children);
          }
        });
      };

      if (value) {
        loop(DocumentTreeData);
      }

      this.setState({
        selectedKeysList: selectedKeysList
      });
      /*
      let selectedKeys = this.state.selectedKeys
      if(value){
        loop(DocumentTreeData)
        if(selectedKeysList.length > 0){
          if(selectedKeys.length === 0) {
            selectedKeys.push(selectedKeysList[0])
          }else{
            if(selectedKeysList.includes(selectedKeys[0])){
              let index = selectedKeysList.indexOf(selectedKeys[0])
              if(selectedKeysList.length>index){
                selectedKeys = [selectedKeysList[index+1]]
              }else{
                selectedKeys = [selectedKeysList[0]]
              }
            }else{
              selectedKeys=[selectedKeysList[0]]
            }
          }
        }
        this.setState({selectedKeys},()=>{
          let expandedKeys = []
          if(selectedKeys && selectedKeys.length>0 && selectedKeys[0]){
            let selectedKeysArr = selectedKeys[0].split('.')
            selectedKeysArr.pop()
            selectedKeysArr.forEach((k)=>{
              if(expandedKeys.length>0){
                expandedKeys.push(expandedKeys[expandedKeys.length-1]+'.'+k)
              }else{
                expandedKeys.push(k)
              }
            })
          }
          if(expandedKeys.length===0){
            expandedKeys = DocumentTreeData.length > 0 && DocumentTreeData[0].key ? [DocumentTreeData[0].key] : []
          }
          this.setState({expandedKeys},()=>{
            // console.log(this.heightcount,jQuery('.rc-tree.myCls.rc-tree-show-line'),jQuery('.rc-tree-treenode-selected'))
            // jQuery('.rc-tree-treenode-selected').focus()
            // $(selectedKeys[0]).focus()
            // if(jQuery('.rc-tree-treenode-selected') && jQuery('.rc-tree-treenode-selected').length>0){
            //   jQuery('.rc-tree-treenode-selected').focus()
            // }
            // document.getElementById(selectedKeys[0]).focus()
            // console.log(document.getElementById('mygundongtiao'))
            // if(jQuery('.rc-tree.myCls.rc-tree-show-line') && jQuery('.rc-tree.myCls.rc-tree-show-line').length>0 && jQuery('.rc-tree-treenode-selected') && jQuery('.rc-tree-treenode-selected').length){
            //   jQuery('.rc-tree.myCls.rc-tree-show-line').scrollTop = jQuery('.rc-tree-treenode-selected').offsetTop-100
            // }
            // console.log(document.getElementByclassName('yy-tab-content'), document.getElementByclassName('rc-tree-node-selected')) // $('. .rc-tree-node-selected')
            // setTimeout(()=>{
            //   console.log(document.getElementByclassName('yy-tab-content'), document.getElementByclassName('rc-tree-node-selected'))
            // },0)
          })
          // console.log(selectedKeys)
        })
      }
      // console.log([selectedKeysList,value,selectedKeys])
      */
    }
  }, {
    key: "loop",
    value: function loop(data) {
      var _this2 = this;

      var selectedKeysList = this.state.selectedKeysList;
      var value = this.state.value;

      if (value && selectedKeysList.length > 0) {
        // console.log(selectedKeysList)
        return selectedKeysList.map(function (item) {
          return React.createElement(TreeNode, {
            title: item.fname,
            isLeaf: true,
            key: item.key,
            code: item.code,
            disabled: item.disabled //className={isflag ? 'yy-search-selected' : ''}

          });
        });
      }

      return data.map(function (item) {
        // let isflag = false
        // if(value && value.length > 0){
        //   let reg = new RegExp(value,'igm')
        //   if(reg.test(item.title)){
        //     selectedKeys.push(item.key)
        //   }
        //   // console.log(isflag)
        // }else{
        //   // console.log(isflag)
        // }
        if (item.children && item.children.length > 0) {
          return React.createElement(TreeNode //title={item.title}
          , {
            title: React.createElement("span", {
              onDoubleClick: _this2.onDoubleClick.bind(_this2, item)
            }, item.title),
            isLeaf: false,
            key: item.key,
            code: item.code,
            disabled: item.disabled //className={isflag ? 'yy-search-selected' : ''}

          }, _this2.loop(item.children));
        } else {
          return React.createElement(TreeNode, {
            title: React.createElement("span", {
              onDoubleClick: _this2.onDoubleClick.bind(_this2, item)
            }, item.title),
            isLeaf: true,
            key: item.key,
            code: item.code,
            disabled: item.disabled //className={isflag ? 'yy-search-selected' : ''}

          });
        }
      });
    }
  }, {
    key: "setFname",
    value: function setFname(data, name) {
      var _this3 = this;

      return data.map(function (item) {
        var title = item.title,
            children = item.children;
        var fname = name ? name.trim() + '/' + title : title;
        item.fname = fname; // console.log(JSON.stringify(children));

        if (children && children.length > 0) {
          item.children = _this3.setFname(children, fname);
        }

        return item; // console.log()
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this4 = this;

      var DocumentTreeData = this.props.DocumentTreeData;
      DocumentTreeData = this.setFname(DocumentTreeData); // console.log(DocumentTreeData)
      // let defaultExpandedKeys = DocumentTreeData.length > 0 && DocumentTreeData[0].key ? [DocumentTreeData[0].key] : []
      // let value = this.state.value
      // let selectedKeys = []
      // const loop = (data)=>{
      //   // console.log(data)
      // }

      return React.createElement("div", {
        className: "yy-tab-content"
      }, React.createElement("form", {
        className: "form-inline"
      }, React.createElement("span", null, this.props.item.positionName), React.createElement("div", {
        className: "form-group"
      }, React.createElement("input", {
        className: "form-control",
        onChange: this.onChange,
        value: this.state.value,
        onKeyPress: function onKeyPress(event) {
          if (event.key === 'Enter') {
            event.preventDefault();
            event.stopPropagation();
            return false;
          }
        }
      })), React.createElement("button", {
        style: {
          marginLeft: '10px'
        },
        className: "btn btn-default",
        onClick: this.onButClick,
        type: "button"
      }, this.props.item.okName)), React.createElement(Tree, {
        id: "mygundongtiao",
        prefixCls: "rc-tree",
        showLine: true,
        showIcon: false,
        checkable: false // defaultExpandAll
        // defaultExpandedKeys={defaultExpandedKeys}
        ,
        expandedKeys: this.state.expandedKeys,
        onExpand: function onExpand(expandedKeys) {
          // console.log(expandedKeys)
          _this4.setState({
            expandedKeys: expandedKeys
          });
        },
        className: "myCls" // autoExpandParent
        // checkStrictly
        ,
        selectedKeys: this.state.selectedKeys,
        onSelect: this.onSelect //expandAction='doubleClick'

      }, this.loop(DocumentTreeData)));
    }
  }]);

  return DocumentComponents;
}(React.Component);

DocumentComponents.propTypes = {
  item: PropTypes.object,
  DocumentTreeData: PropTypes.array
};
DocumentComponents.defaultProps = {
  item: {},
  DocumentTreeData: []
};
polyfill(DocumentComponents);
export default DocumentComponents;
